@@ -1,7 +1,7 @@
 package Gapp::Moose::Role;
-
-our $VERSION = 0.01;
-our $AUTHORITY = 'cpan:JHALLOCK';
+{
+  $Gapp::Moose::Role::VERSION = '0.487';
+}
 
 use Moose::Role;
 use Moose::Meta::Method;
@@ -11,11 +11,14 @@ use Gapp;
 use Gapp::Gtk2;
 use Gapp::Moose::Meta::Attribute::Trait::GappActionGroup;
 use Gapp::Moose::Meta::Attribute::Trait::GappAssistant;
+use Gapp::Moose::Meta::Attribute::Trait::GappCheckButton;
 use Gapp::Moose::Meta::Attribute::Trait::GappComboBox;
 use Gapp::Moose::Meta::Attribute::Trait::GappBox;
 use Gapp::Moose::Meta::Attribute::Trait::GappButton;
 use Gapp::Moose::Meta::Attribute::Trait::GappDateEntry;
+use Gapp::Moose::Meta::Attribute::Trait::GappEntry;
 use Gapp::Moose::Meta::Attribute::Trait::GappEventBox;
+use Gapp::Moose::Meta::Attribute::Trait::GappExpander;
 use Gapp::Moose::Meta::Attribute::Trait::GappFileChooserDialog;
 use Gapp::Moose::Meta::Attribute::Trait::GappFileFilter;
 use Gapp::Moose::Meta::Attribute::Trait::GappFrame;
